pub fn sgit(args: &[&str], config: &ValetConfig) -> Result<Output>Expand description
Runs a git command against the valet bare repo + work-tree (does not check exit status)
pub fn sgit(args: &[&str], config: &ValetConfig) -> Result<Output>Runs a git command against the valet bare repo + work-tree (does not check exit status)